#
# spec file for package python-sox
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-sox
Version:        1.5.0
Release:        1.6
License:        BSD-3-Clause
Summary:        Python wrapper around SoX
URL:            https://github.com/rabitt/pysox
Group:          Development/Languages/Python
Source:         https://github.com/marl/pysox/archive/v%{version}/sox-%{version}.tar.gz
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module soundfile}
BuildRequires:  %{python_module typing-extensions}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  sox
Requires:       python-numpy
Requires:       python-typing-extensions
Requires:       sox
BuildArch:      noarch

%python_subpackages

%description
SOX is intended to be the Swiss Army knife of sound processing tools.
It does many things, it just does not do them all well. Sooner or later
it will come in very handy. SOX is really only usable day-to-day if you
hide the wacky options with one-line shell scripts.

This is a Python wrapper for SOX.

%prep
%autosetup -p1 -n pysox-%{version}
sed -i -e '/^#!\//, 1d' sox/*.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Fails in i586
donttest="test_multichannel or test_valid"
%pytest -k "not ($donttest)"

%files %{python_files}
%license LICENSE
%{python_sitelib}/sox-%{version}*-info/
%{python_sitelib}/sox

%changelog
* Tue May 14 2024 Daniel Garcia <daniel.garcia@suse.com>
- Build package from source
- Run tests
- Update to 1.5.0
  - This is the first stable release of the 1.5 series. It is
    functionally identical to 1.5-rc1. Compared to 1.4, the main
    change is that we have dropped support for EOL Python (3.7 and
    earlier) and have added support for Python up to 3.12 (@hugovk and
    @lostanlen).
  - New features:
  * pathlib support (#124), @cjacoby
  * type hints (#129), @hadware and @rabitt
* Tue Oct 26 2021 Axel Braun <axel.braun@gmx.de>
- version 1.4.1
  changes up to version 1.4.0:
  * added .build_array() which supports file or in memory inputs and array outputs
  * added .build_file() - an alias to .build()
  * refactored .build() function to support file or in-memory array inputs and file outputs
  * the call to subprocess calls the binary directly (shell=False)
  * file_info methods return None instead of 0 when the value is not available
  * fixed bug in file_info.bitrate(), which was returning bitdepth
  * added file_info.bitdepth()
  * added Windows support for soxi
  * added configurable logging
  * .trim() can be called with only the start time specificed
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- initial version
